aboutsummaryrefslogtreecommitdiff
path: root/src/make.bash
diff options
context:
space:
mode:
authorRuss Cox <rsc@golang.org>2023-07-23 05:21:31 -0400
committerGopher Robot <gobot@golang.org>2023-07-24 02:49:20 +0000
commit7141d1e6d820241de321f8a9d336871737560950 (patch)
tree06ed851d93336dfcf733df60a5469d512618d9b2 /src/make.bash
parentb02725a8897ec46e26b99e3be9b9805021c77064 (diff)
downloadgo-7141d1e6d820241de321f8a9d336871737560950.tar.xz
make.bash,bat,rc: use Go 1.20.6 instead of Go 1.17.13
This was missed in the update of the bootstrap toolchain and should help people who don't set GOROOT_BOOTSTRAP and instead assume these scripts will find the right one. For #54265. Change-Id: I37a0d0976006d13b73df00013780be5abf202e91 Reviewed-on: https://go-review.googlesource.com/c/go/+/512275 Run-TryBot: Russ Cox <rsc@golang.org> TryBot-Result: Gopher Robot <gobot@golang.org> Reviewed-by: Cherry Mui <cherryyz@google.com> Auto-Submit: Russ Cox <rsc@golang.org> Reviewed-by: Dmitri Shuralyov <dmitshur@golang.org>
Diffstat (limited to 'src/make.bash')
-rwxr-xr-xsrc/make.bash8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/make.bash b/src/make.bash
index 755b3b0b9e..e8f002adb0 100755
--- a/src/make.bash
+++ b/src/make.bash
@@ -67,14 +67,14 @@
# timing information to this file. Useful for profiling where the
# time goes when these scripts run.
#
# GOROOT_BOOTSTRAP: A working Go tree >= Go 1.17.13 for bootstrap.
# If $GOROOT_BOOTSTRAP/bin/go is missing, $(go env GOROOT) is
# tried for all "go" in $PATH. By default, one of $HOME/go1.17.13,
# $HOME/sdk/go1.17.13, or $HOME/go1.4, whichever exists, in that order.
# We still check $HOME/go1.4 to allow for build scripts that still hard-code
# that name even though they put newer Go toolchains there.
-bootgo=1.17.13
+bootgo=1.20.6
set -e
@@ -67,14 +67,14 @@
# time goes when these scripts run.
#
-# GOROOT_BOOTSTRAP: A working Go tree >= Go 1.17.13 for bootstrap.
+# GOROOT_BOOTSTRAP: A working Go tree >= Go 1.20.6 for bootstrap.
# If $GOROOT_BOOTSTRAP/bin/go is missing, $(go env GOROOT) is
@@ -67,14 +67,14 @@
# If $GOROOT_BOOTSTRAP/bin/go is missing, $(go env GOROOT) is
-# tried for all "go" in $PATH. By default, one of $HOME/go1.17.13,
-# $HOME/sdk/go1.17.13, or $HOME/go1.4, whichever exists, in that order.
+# tried for all "go" in $PATH. By default, one of $HOME/go1.20.6,
+# $HOME/sdk/go1.20.6, or $HOME/go1.4, whichever exists, in that order.
# We still check $HOME/go1.4 to allow for build scripts that still hard-code
# that name even though they put newer Go toolchains there.